# User Documentation

User documentation is hosted [here](https://fluid-dynamics-group.github.io/distribute-docs).

## Building Locally

You will have to install [`mdbook`](https://rust-lang.github.io/mdBook/guide/installation.html)

```
mdbook watch ./docs --open
```
